@@ -8,7 +8,7 @@ package Future::AsyncAwait;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Carp;
 
@@ -271,7 +271,7 @@ sub import_into
 
 "Awaiting The Future" - TPC in Amsterdam 2017
 
-L<(slides)|https://docs.google.com/presentation/d/13x5l8Rohv_RjWJ0OTvbsWMXKoNEWREZ4GfKHVykqUvc/edit#slide=id.p>
+L<https://www.youtube.com/watch?v=Xf7rStpNaT0> L<(slides)|https://docs.google.com/presentation/d/13x5l8Rohv_RjWJ0OTvbsWMXKoNEWREZ4GfKHVykqUvc/edit#slide=id.p>
 
 =back
 
@@ -297,7 +297,7 @@ Clean up the implementation; check for and fix memory leaks.
 
 =item *
 
-Support older versions of perl than 5.24.
+Support older versions of perl than 5.20.
 
 L<https://rt.cpan.org/Ticket/Display.html?id=122252>
 
